@@ -24,10 +24,10 @@ class RobotConnection(object):
         self.queue_path = data_dir + "EventQueue"
         self.state_path = data_dir + "RobotState.json"
         self.event_buffer = []  # where events that need to be sent are stored
-        self.state_dict = dict()  # where robot state json is parsed into
+        self.sensors = dict()  # where robot state json is parsed into
         self.should_destroy = False  # should this connection end
         self.event_buffer_lock = threading.Lock()  # lock for threads wanting to access event_buffer
-        self.state_dict_lock = threading.Lock()
+        self.sensors_lock = threading.Lock()
 
     def queue_event(self, event_text):
 
@@ -83,9 +83,9 @@ class RobotConnection(object):
             try:
 
                 state_file = open(self.state_path, "r")
-                with self.state_dict_lock:
+                with self.sensors_lock:
 
-                    self.state_dict = json.load(state_file)
+                    self.sensors = json.load(state_file)
 
             except (EnvironmentError, json.JSONDecodeError) as e:
 
